{% extends "base.html" %}
{% load i18n %}

{% block title %}
  {% trans "E-mail envoyé" %}
{% endblock %}

{% block content %}

<p class="text-semibold text-color-heading">
  Please, check your mailbox
</p>

<p class="text-color-heading">We have just sent you the instructions to define your password.</p>

<div class="segment full margin-top-large">
  <a class="link" style="font-size: 0.8em;" href="https://spacelinkers.finance/legal_Imprint.html">Terms & Conditions</a>&nbsp;-&nbsp;<a class="link" style="font-size: 0.8em;" href="https://spacelinkers.finance/legal_Imprint.html#sce2-data-confidentiality">Privacy Policy</a>
</div>

{% endblock %}